Learn R Programming

parboost (version 0.1.4)

parboost_fit: Fit individual parboost component using mboost

Description

Internal function to fit mboost model on a subset of the data

Usage

parboost_fit(subsample_indices, data = NULL, path_to_data, data_import_function, preprocessing, seed, formula, baselearner, family, control, tree_controls, cv, cores_cv = detectCores(), folds, stepsize_mstop)

Arguments

subsample_indices
A numeric vector containing the indices of the subsample
data
A data frame containing the variables in the model. It is recommended to use path_to_data instead for IO efficiency. Defaults to NULL
path_to_data
A string with the path to the data.
data_import_function
What function should be used to import the data?
preprocessing
Optional preprocessing function to apply to the data passed from parboost
seed
Set a seed for reproducible results.
formula
Formula for mboost.
baselearner
Character string determining the type of base learner.
family
mboost family
control
mboost control
tree_controls
party control
cv
Cross-validate?
cores_cv
Number of cores to use during cv.
folds
Number of folds to use for cv.
stepsize_mstop
Stepsize used for optimizing mstop.

Value

The fitted submodel and its predictions

Details

Fits a mboost model on each subset of the data